@@ -3,12 +3,12 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-use 5.020;
-use experimental qw(postderef signatures);
+use 5.024;
 use strictures 2;
 use Carp;
 use List::Util 1.26 qw(sum0);
 use Moo;
+use experimental qw(signatures);
 use Math::Bezier ();
 use MIDI::Util   qw(
     dura_size
@@ -25,7 +25,7 @@ use MIDI::Drummer::Tiny::Types qw(:all);
 use Data::Dumper::Compact      qw(ddc);
 use namespace::clean;
 
-our $VERSION = '0.6001';
+our $VERSION = '0.6002';
 
 use constant STRAIGHT => 50;    # Swing percent
 
@@ -311,44 +311,96 @@ for my $is ( keys %attr_defaults ) {
     }
 }
 
-#pod =head1 KIT
+#pod =kit metronome
 #pod
-#pod =over 4
+#pod =over
 #pod
-#pod =item click, bell (metronome)
+#pod =item click, bell
+#pod
+#pod =back
+#pod
+#pod =kit hi-hats
+#pod
+#pod =over
 #pod
 #pod =item open_hh, closed_hh, pedal_hh
 #pod
+#pod =back
+#pod
+#pod =kit crash and splash cymbals
+#pod
+#pod =over
+#pod
 #pod =item crash1, crash2, splash, china
 #pod
+#pod =back
+#pod
+#pod =kit ride cymbals
+#pod
+#pod =over
+#pod
 #pod =item ride1, ride2, ride_bell
 #pod
+#pod =back
+#pod
+#pod =kit snare drums and handclaps
+#pod
+#pod =over
+#pod
 #pod =item snare, acoustic_snare, electric_snare, side_stick, clap
 #pod
+#pod Where the B<snare> is by default the same as the B<acoustic_snare> but
+#pod can be overridden with the B<electric_snare> (C<40>).
+#pod
 #pod =back
 #pod
-#pod Where the B<snare> is by default the same as the B<acoustic_snare> but
-#pod can be overridden with the B<electric_snare> (C<'n40'>).
+#pod =kit tom-toms
 #pod
-#pod =over 4
+#pod =over
 #pod
 #pod =item hi_tom, hi_mid_tom, low_mid_tom, low_tom, hi_floor_tom, low_floor_tom
 #pod
+#pod =back
+#pod
+#pod =kit bass drums
+#pod
+#pod =over
+#pod
 #pod =item kick, acoustic_bass, electric_bass
 #pod
+#pod Where the B<kick> is by default the same as the B<acoustic_bass> but
+#pod can be overridden with the B<electric_bass> (C<36>).
+#pod
 #pod =back
 #pod
-#pod Where the B<kick> is by default the same as the B<acoustic_bass> but
-#pod can be overridden with the B<electric_bass> (C<'n36'>).
+#pod =kit auxiliary percussion
 #pod
-#pod =over 4
+#pod =over
 #pod
 #pod =item tambourine, cowbell, vibraslap
 #pod
+#pod =back
+#pod
+#pod =kit Latin and African drums
+#pod
+#pod =over
+#pod
 #pod =item hi_bongo, low_bongo, mute_hi_conga, open_hi_conga, low_conga, high_timbale, low_timbale
 #pod
+#pod =back
+#pod
+#pod =kit Latin and African auxiliary percussion
+#pod
+#pod =over
+#pod
 #pod =item high_agogo, low_agogo, cabasa, maracas, short_whistle, long_whistle, short_guiro, long_guiro, claves, hi_wood_block, low_wood_block, mute_cuica, open_cuica
 #pod
+#pod =back
+#pod
+#pod =kit triangles
+#pod
+#pod =over
+#pod
 #pod =item mute_triangle, open_triangle
 #pod
 #pod =back
@@ -426,24 +478,66 @@ has snare => (
     default => 38,               # Alt: 40
 );
 
-#pod =head1 DURATIONS
+#pod =duration whole notes
 #pod
-#pod =over 4
+#pod =over
 #pod
 #pod =item whole, triplet_whole, dotted_whole, double_dotted_whole
 #pod
+#pod =back
+#pod
+#pod =duration half notes
+#pod
+#pod =over
+#pod
 #pod =item half, triplet_half, dotted_half, double_dotted_half
 #pod
+#pod =back
+#pod
+#pod =duration quarter notes
+#pod
+#pod =over
+#pod
 #pod =item quarter, triplet_quarter, dotted_quarter, double_dotted_quarter
 #pod
+#pod =back
+#pod
+#pod =duration eighth notes
+#pod
+#pod =over
+#pod
 #pod =item eighth, triplet_eighth, dotted_eighth, double_dotted_eighth
 #pod
+#pod =back
+#pod
+#pod =duration sixteenth notes
+#pod
+#pod =over
+#pod
 #pod =item sixteenth, triplet_sixteenth, dotted_sixteenth, double_dotted_sixteenth
 #pod
+#pod =back
+#pod
+#pod =duration thirty-secondth notes
+#pod
+#pod =over
+#pod
 #pod =item thirtysecond, triplet_thirtysecond, dotted_thirtysecond, double_dotted_thirtysecond
 #pod
+#pod =back
+#pod
+#pod =duration sixty-fourth notes
+#pod
+#pod =over
+#pod
 #pod =item sixtyfourth, triplet_sixtyfourth, dotted_sixtyfourth, double_dotted_sixtyfourth
 #pod
+#pod =back
+#pod
+#pod =duration one-twenty-eighth notes
+#pod
+#pod =over
+#pod
 #pod =item onetwentyeighth, triplet_onetwentyeighth, dotted_onetwentyeighth, double_dotted_onetwentyeighth
 #pod
 #pod =back
@@ -1356,7 +1450,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.6001
+version 0.6002
 
 =head1 SYNOPSIS
 
@@ -1834,72 +1928,178 @@ Play the score with C<fluidsynth>.
 
 See L<MIDI::Util/play_fluidsynth> for more details.
 
-=for Pod::Coverage BUILD
+=head1 NOTE ATTRIBUTES
 
-=head1 KIT
+Any of these attributes may be changed when calling L</new>.
+Drumkit values must be a valid
+L<MIDI::Drummer::Tiny/PercussionNote>,
+while note duration values must be a valid
+L<MIDI::Drummer::Tiny/Duration>.
 
-=over 4
+=head2 DRUMKIT
 
-=item click, bell (metronome)
+=head3 metronome
+
+=over
+
+=item click, bell
+
+=back
+
+=head3 hi-hats
+
+=over
 
 =item open_hh, closed_hh, pedal_hh
 
+=back
+
+=head3 crash and splash cymbals
+
+=over
+
 =item crash1, crash2, splash, china
 
+=back
+
+=head3 ride cymbals
+
+=over
+
 =item ride1, ride2, ride_bell
 
+=back
+
+=head3 snare drums and handclaps
+
+=over
+
 =item snare, acoustic_snare, electric_snare, side_stick, clap
 
+Where the B<snare> is by default the same as the B<acoustic_snare> but
+can be overridden with the B<electric_snare> (C<40>).
+
 =back
 
-Where the B<snare> is by default the same as the B<acoustic_snare> but
-can be overridden with the B<electric_snare> (C<'n40'>).
+=head3 tom-toms
 
-=over 4
+=over
 
 =item hi_tom, hi_mid_tom, low_mid_tom, low_tom, hi_floor_tom, low_floor_tom
 
+=back
+
+=head3 bass drums
+
+=over
+
 =item kick, acoustic_bass, electric_bass
 
+Where the B<kick> is by default the same as the B<acoustic_bass> but
+can be overridden with the B<electric_bass> (C<36>).
+
 =back
 
-Where the B<kick> is by default the same as the B<acoustic_bass> but
-can be overridden with the B<electric_bass> (C<'n36'>).
+=head3 auxiliary percussion
 
-=over 4
+=over
 
 =item tambourine, cowbell, vibraslap
 
+=back
+
+=head3 Latin and African drums
+
+=over
+
 =item hi_bongo, low_bongo, mute_hi_conga, open_hi_conga, low_conga, high_timbale, low_timbale
 
+=back
+
+=head3 Latin and African auxiliary percussion
+
+=over
+
 =item high_agogo, low_agogo, cabasa, maracas, short_whistle, long_whistle, short_guiro, long_guiro, claves, hi_wood_block, low_wood_block, mute_cuica, open_cuica
 
+=back
+
+=head3 triangles
+
+=over
+
 =item mute_triangle, open_triangle
 
 =back
 
-=head1 DURATIONS
+=head2 DURATIONS
 
-=over 4
+=head3 whole notes
+
+=over
 
 =item whole, triplet_whole, dotted_whole, double_dotted_whole
 
+=back
+
+=head3 half notes
+
+=over
+
 =item half, triplet_half, dotted_half, double_dotted_half
 
+=back
+
+=head3 quarter notes
+
+=over
+
 =item quarter, triplet_quarter, dotted_quarter, double_dotted_quarter
 
+=back
+
+=head3 eighth notes
+
+=over
+
 =item eighth, triplet_eighth, dotted_eighth, double_dotted_eighth
 
+=back
+
+=head3 sixteenth notes
+
+=over
+
 =item sixteenth, triplet_sixteenth, dotted_sixteenth, double_dotted_sixteenth
 
+=back
+
+=head3 thirty-secondth notes
+
+=over
+
 =item thirtysecond, triplet_thirtysecond, dotted_thirtysecond, double_dotted_thirtysecond
 
+=back
+
+=head3 sixty-fourth notes
+
+=over
+
 =item sixtyfourth, triplet_sixtyfourth, dotted_sixtyfourth, double_dotted_sixtyfourth
 
+=back
+
+=head3 one-twenty-eighth notes
+
+=over
+
 =item onetwentyeighth, triplet_onetwentyeighth, dotted_onetwentyeighth, double_dotted_onetwentyeighth
 
 =back
 
+=for Pod::Coverage BUILD
+
 =head1 SEE ALSO
 
 The F<t/*> test file and the F<eg/*> programs in this distribution.
